==> phpAdsNew-2.0.tar.gz: phpAdsNew-2.0/language/italian/res-iso3166.lang.php <==
<?php // $Revision: 1.2.2.3 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2003 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


$phpAds_ISO3166['AF'] = "Afghanistan";
$phpAds_ISO3166['AL'] = "Albania";
$phpAds_ISO3166['DZ'] = "Algeria";
$phpAds_ISO3166['AS'] = "American Samoa";
$phpAds_ISO3166['AD'] = "Andorra";
$phpAds_ISO3166['AO'] = "Angola";
$phpAds_ISO3166['AI'] = "Anguilla";
$phpAds_ISO3166['AQ'] = "Antarctica"; 
$phpAds_ISO3166['AG'] = "Antigua e Barbuda"; 
$phpAds_ISO3166['AR'] = "Argentina";
$phpAds_ISO3166['AM'] = "Armenia";
$phpAds_ISO3166['AW'] = "Aruba";
$phpAds_ISO3166['AU'] = "Australia";
$phpAds_ISO3166['AT'] = "Austria";
$phpAds_ISO3166['AZ'] = "Azerbaigian";
$phpAds_ISO3166['BS'] = "Bahamas";
$phpAds_ISO3166['BH'] = "Bahrain";
$phpAds_ISO3166['BD'] = "Bangladesh";
$phpAds_ISO3166['BB'] = "Barbados";
$phpAds_ISO3166['BY'] = "Belarus";
$phpAds_ISO3166['BE'] = "Belgio";
$phpAds_ISO3166['BZ'] = "Belize";
$phpAds_ISO3166['BJ'] = "Benin"; 
$phpAds_ISO3166['BM'] = "Bermuda";
$phpAds_ISO3166['BT'] = "Bhutan";
$phpAds_ISO3166['BO'] = "Bolivia";
$phpAds_ISO3166['BA'] = "Bosnia Herzegovina";
$phpAds_ISO3166['BW'] = "Botswana";
$phpAds_ISO3166['BV'] = "Isola Bouvet";
$phpAds_ISO3166['BR'] = "Brasile";
$phpAds_ISO3166['IO'] = "Territorio Britannico dell'Oceano Indiano";
$phpAds_ISO3166['BN'] = "Brunei";
$phpAds_ISO3166['BG'] = "Bulgaria";
$phpAds_ISO3166['BF'] = "Burkina Faso"; 
$phpAds_ISO3166['BI'] = "Burundi";
$phpAds_ISO3166['KH'] = "Cambogia";
$phpAds_ISO3166['CM'] = "Camerun"; 
$phpAds_ISO3166['CA'] = "Canada";
$phpAds_ISO3166['CV'] = "Capo Verde"; 
$phpAds_ISO3166['KY'] = "Cayman";
$phpAds_ISO3166['CF'] = "Repubblica Centrafricana";
$phpAds_ISO3166['TD'] = "Ciad"; 
$phpAds_ISO3166['CL'] = "Cile";
$phpAds_ISO3166['CN'] = "Cina";
$phpAds_ISO3166['CX'] = "Isola Christmas"; 
$phpAds_ISO3166['CC'] = "Isole Cocos (Keeling)"; 
$phpAds_ISO3166['CO'] = "Colombia";
$phpAds_ISO3166['KM'] = "Comore";
$phpAds_ISO3166['CG'] = "Congo"; 
$phpAds_ISO3166['CD'] = "Repubblica del Congo (ex-Zaire)"; 
$phpAds_ISO3166['CK'] = "Isole Cook"; 
$phpAds_ISO3166['CR'] = "Costarica";
$phpAds_ISO3166['CI'] = "Costa d'Avorio"; 
$phpAds_ISO3166['HR'] = "Croazia";
$phpAds_ISO3166['CU'] = "Cuba";
$phpAds_ISO3166['CY'] = "Cipro";
$phpAds_ISO3166['CZ'] = "Repubblica Ceca";
$phpAds_ISO3166['DK'] = "Danimarca";
$phpAds_ISO3166['DJ'] = "Gibuti";
$phpAds_ISO3166['DM'] = "Dominica"; 
$phpAds_ISO3166['DO'] = "Repubblica Dominicana";
$phpAds_ISO3166['TP'] = "Timor Est";
$phpAds_ISO3166['EC'] = "Ecuador";
$phpAds_ISO3166['EG'] = "Egitto";
$phpAds_ISO3166['SV'] = "El Salvador";
$phpAds_ISO3166['GQ'] = "Guinea Equatoriale"; 
$phpAds_ISO3166['ER'] = "Eritrea";
$phpAds_ISO3166['EE'] = "Estonia";
$phpAds_ISO3166['ET'] = "Etiopia";
$phpAds_ISO3166['EU'] = "Unione Europea";
$phpAds_ISO3166['FK'] = "Isole Falkland (o Malvine)";
$phpAds_ISO3166['FO'] = "Isole F&aelig;r&oslash;er"; 
$phpAds_ISO3166['FJ'] = "Figi";
$phpAds_ISO3166['FI'] = "Finlandia";
$phpAds_ISO3166['FR'] = "Francia";
$phpAds_ISO3166['FX'] = "Francia, Metropolitana"; 
$phpAds_ISO3166['GF'] = "Guyana Francese";
$phpAds_ISO3166['PF'] = "Polinesia Francese";
$phpAds_ISO3166['TF'] = "Territori Francesi del Sud";
$phpAds_ISO3166['GA'] = "Gabon"; 
$phpAds_ISO3166['GM'] = "Gambia";
$phpAds_ISO3166['GE'] = "Georgia";
$phpAds_ISO3166['DE'] = "Germania";
$phpAds_ISO3166['GH'] = "Ghana";
$phpAds_ISO3166['GI'] = "Gibilterra";
$phpAds_ISO3166['GR'] = "Grecia";
$phpAds_ISO3166['GL'] = "Groenlandia"; 
$phpAds_ISO3166['GD'] = "Grenada"; 
$phpAds_ISO3166['GP'] = "Guadalupa"; 
$phpAds_ISO3166['GU'] = "Guam"; 
$phpAds_ISO3166['GT'] = "Guatemala";
$phpAds_ISO3166['GN'] = "Guinea"; 
$phpAds_ISO3166['GW'] = "Guinea-Bissau"; 
$phpAds_ISO3166['GY'] = "Guyana";
$phpAds_ISO3166['HT'] = "Haiti";
$phpAds_ISO3166['HM'] = "Isole Heard e Mc Donald"; 
$phpAds_ISO3166['VA'] = "Vaticano"; 
$phpAds_ISO3166['HN'] = "Honduras";
$phpAds_ISO3166['HK'] = "Hong Kong";
$phpAds_ISO3166['HU'] = "Ungheria";
$phpAds_ISO3166['IS'] = "Islanda"; 
$phpAds_ISO3166['IN'] = "India";
$phpAds_ISO3166['ID'] = "Indonesia";
$phpAds_ISO3166['IR'] = "Iran";
$phpAds_ISO3166['IQ'] = "Iraq";
$phpAds_ISO3166['IE'] = "Irlanda";
$phpAds_ISO3166['IL'] = "Israele";
$phpAds_ISO3166['IT'] = "Italia";
$phpAds_ISO3166['JM'] = "Giamaica";
$phpAds_ISO3166['JP'] = "Giappone";
$phpAds_ISO3166['JO'] = "Giordania";
$phpAds_ISO3166['KZ'] = "Kazakistan";
$phpAds_ISO3166['KE'] = "Kenya";
$phpAds_ISO3166['KI'] = "Kiribati"; 
$phpAds_ISO3166['KP'] = "Corea del Nord"; 
$phpAds_ISO3166['KR'] = "Corea del Sud"; 
$phpAds_ISO3166['KW'] = "Kuwait";
$phpAds_ISO3166['KG'] = "Kirghizistan"; 
$phpAds_ISO3166['LA'] = "Laos";
$phpAds_ISO3166['LV'] = "Lettonia";
$phpAds_ISO3166['LB'] = "Libano";
$phpAds_ISO3166['LS'] = "Lesotho";
$phpAds_ISO3166['LR'] = "Liberia";
$phpAds_ISO3166['LY'] = "Libia";
$phpAds_ISO3166['LI'] = "Liechtenstein"; 
$phpAds_ISO3166['LT'] = "Lituania"; 
$phpAds_ISO3166['LU'] = "Lussemburgo";
$phpAds_ISO3166['MO'] = "Macao";
$phpAds_ISO3166['MK'] = "Macedonia";
$phpAds_ISO3166['MG'] = "Madagascar"; 
$phpAds_ISO3166['MW'] = "Malawi";
$phpAds_ISO3166['MY'] = "Malaysia";
$phpAds_ISO3166['MV'] = "Maldive";
$phpAds_ISO3166['ML'] = "Mali"; 
$phpAds_ISO3166['MT'] = "Malta";
$phpAds_ISO3166['MH'] = "Isole Marshall"; 
$phpAds_ISO3166['MQ'] = "Martinica"; 
$phpAds_ISO3166['MR'] = "Mauritania";
$phpAds_ISO3166['MU'] = "Maurizio";
$phpAds_ISO3166['YT'] = "Mayotte"; 
$phpAds_ISO3166['MX'] = "Messico";
$phpAds_ISO3166['FM'] = "Micronesia"; 
$phpAds_ISO3166['MD'] = "Moldavia";
$phpAds_ISO3166['MC'] = "Monaco";
$phpAds_ISO3166['MN'] = "Mongolia";
$phpAds_ISO3166['MS'] = "Montserrat"; 
$phpAds_ISO3166['MA'] = "Marocco";
$phpAds_ISO3166['MZ'] = "Mozambico";
$phpAds_ISO3166['MM'] = "Myanmar";
$phpAds_ISO3166['NA'] = "Namibia";
$phpAds_ISO3166['NR'] = "Nauru"; 
$phpAds_ISO3166['NP'] = "Nepal";
$phpAds_ISO3166['NL'] = "Paesi Bassi";
$phpAds_ISO3166['AN'] = "Antille Olandesi";
$phpAds_ISO3166['NC'] = "Nuova Caledonia"; 
$phpAds_ISO3166['NZ'] = "Nuova Zelanda";
$phpAds_ISO3166['NI'] = "Nicaragua";
$phpAds_ISO3166['NE'] = "Niger"; 
$phpAds_ISO3166['NG'] = "Nigeria";
$phpAds_ISO3166['NU'] = "Niue"; 
$phpAds_ISO3166['NF'] = "Isola Norfolk"; 
$phpAds_ISO3166['MP'] = "Marianne Settentrionali"; 
$phpAds_ISO3166['NO'] = "Norvegia";
$phpAds_ISO3166['OM'] = "Oman";
$phpAds_ISO3166['PK'] = "Pakistan";
$phpAds_ISO3166['PW'] = "Palau"; 
$phpAds_ISO3166['PA'] = "Panama";
$phpAds_ISO3166['PG'] = "Papua Nuova Guinea";
$phpAds_ISO3166['PY'] = "Paraguay";
$phpAds_ISO3166['PE'] = "Per&ugrave;";
$phpAds_ISO3166['PH'] = "Filippine";
$phpAds_ISO3166['PN'] = "Isole Pitcairn"; 
$phpAds_ISO3166['PL'] = "Polonia";
$phpAds_ISO3166['PT'] = "Territori Palestinesi Occupati";
$phpAds_ISO3166['PT'] = "Portogallo";
$phpAds_ISO3166['PR'] = "Portirico"; 
$phpAds_ISO3166['QA'] = "Qatar";
$phpAds_ISO3166['RE'] = "Riunione"; 
$phpAds_ISO3166['RO'] = "Romania";
$phpAds_ISO3166['RU'] = "Russia";
$phpAds_ISO3166['RW'] = "Ruanda";
$phpAds_ISO3166['KN'] = "Saint Kitts e Nevis"; 
$phpAds_ISO3166['LC'] = "Saint Lucia"; 
$phpAds_ISO3166['VC'] = "Saint Vincent e Grenadines"; 
$phpAds_ISO3166['WS'] = "Samoa";
$phpAds_ISO3166['SM'] = "San Marino";
$phpAds_ISO3166['ST'] = "S&atilde;o Tom&eacute; e Principe"; 
$phpAds_ISO3166['SA'] = "Arabia Saudita";
$phpAds_ISO3166['SN'] = "Senegal"; 
$phpAds_ISO3166['SC'] = "Seychelles";
$phpAds_ISO3166['SL'] = "Sierra Leone";
$phpAds_ISO3166['SG'] = "Singapore";
$phpAds_ISO3166['SK'] = "Slovacchia";
$phpAds_ISO3166['SI'] = "Slovenia";
$phpAds_ISO3166['SO'] = "Somalia";
$phpAds_ISO3166['SB'] = "Isole Salomone"; 
$phpAds_ISO3166['ZA'] = "Sudafrica";
$phpAds_ISO3166['GS'] = "Georgia Meridionale e isole South Sandwich"; 
$phpAds_ISO3166['ES'] = "Spagna";
$phpAds_ISO3166['LK'] = "Sri Lanka";
$phpAds_ISO3166['SH'] = "Sant'Elena"; 
$phpAds_ISO3166['PM'] = "Saint Pierre e Miquelon"; 
$phpAds_ISO3166['SD'] = "Sudan";
$phpAds_ISO3166['SR'] = "Suriname";
$phpAds_ISO3166['SJ'] = "Svalbard e isole Jan Mayen"; 
$phpAds_ISO3166['SZ'] = "Swaziland";
$phpAds_ISO3166['SE'] = "Svezia";
$phpAds_ISO3166['CH'] = "Svizzera";
$phpAds_ISO3166['SY'] = "Syrian Arab Republic";
$phpAds_ISO3166['TW'] = "Taiwan";
$phpAds_ISO3166['TJ'] = "Tagikistan";
$phpAds_ISO3166['TZ'] = "Tanzania";
$phpAds_ISO3166['TH'] = "Thailandia";
$phpAds_ISO3166['TG'] = "Togo"; 
$phpAds_ISO3166['TK'] = "Tokelau"; 
$phpAds_ISO3166['TO'] = "Tonga";
$phpAds_ISO3166['TT'] = "Trinidad e Tobago";
$phpAds_ISO3166['TN'] = "Tunisia";
$phpAds_ISO3166['TR'] = "Turchia";
$phpAds_ISO3166['TM'] = "Turkmenistan";
$phpAds_ISO3166['TC'] = "Isole Turks e Caicos"; 
$phpAds_ISO3166['TV'] = "Tuvalu"; 
$phpAds_ISO3166['UG'] = "Uganda";
$phpAds_ISO3166['UA'] = "Ucraina";
$phpAds_ISO3166['AE'] = "Emirati Arabi Uniti"; 
$phpAds_ISO3166['GB'] = "Gran Bretagna";
$phpAds_ISO3166['US'] = "Stati Uniti";
$phpAds_ISO3166['UM'] = "United States Minor Outlying Islands"; 
$phpAds_ISO3166['UY'] = "Uruguay";
$phpAds_ISO3166['UZ'] = "Uzbekistan";
$phpAds_ISO3166['VU'] = "Vanuatu";
$phpAds_ISO3166['VE'] = "Venezuela";
$phpAds_ISO3166['VN'] = "Vietnam";
$phpAds_ISO3166['VG'] = "Isole Vergini Britanniche"; 
$phpAds_ISO3166['VI'] = "Isole Vergini"; 
$phpAds_ISO3166['WF'] = "Isole Wallis e Futuna"; 
$phpAds_ISO3166['EH'] = "Sahara Occidentale"; 
$phpAds_ISO3166['YE'] = "Yemen";
$phpAds_ISO3166['YU'] = "Yugoslavia";
$phpAds_ISO3166['ZM'] = "Zambia";
$phpAds_ISO3166['ZW'] = "Zimbabwe";


// MaxMind Geo-IP special codes
$phpAds_ISO3166['A1'] = "Proxy Anonimo";
$phpAds_ISO3166['A2'] = "Provider Satellitare";


?>

==> phpAdsNew-2.0.7.tar.gz: phpAdsNew-2.0.7/language/italian/res-iso3166.lang.php <==
<?php // $Revision: 1.2.2.5 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2005 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


$phpAds_ISO3166['AF'] = "Afghanistan";
$phpAds_ISO3166['AL'] = "Albania";
$phpAds_ISO3166['DZ'] = "Algeria";
$phpAds_ISO3166['AS'] = "American Samoa";
$phpAds_ISO3166['AD'] = "Andorra";
$phpAds_ISO3166['AO'] = "Angola";
$phpAds_ISO3166['AI'] = "Anguilla";
$phpAds_ISO3166['AQ'] = "Antartide"; 
$phpAds_ISO3166['AG'] = "Antigua e Barbuda"; 
$phpAds_ISO3166['AR'] = "Argentina";
$phpAds_ISO3166['AP'] = "ARIPO (African Regional...)";
$phpAds_ISO3166['AM'] = "Armenia";
$phpAds_ISO3166['AW'] = "Aruba";
$phpAds_ISO3166['AU'] = "Australia";
$phpAds_ISO3166['AT'] = "Austria";
$phpAds_ISO3166['AZ'] = "Azerbaigian";
$phpAds_ISO3166['BS'] = "Bahamas";
$phpAds_ISO3166['BH'] = "Bahrein";
$phpAds_ISO3166['BD'] = "Bangladesh";
$phpAds_ISO3166['BB'] = "Barbados";
$phpAds_ISO3166['BY'] = "Bielorussia";
$phpAds_ISO3166['BE'] = "Belgio";
$phpAds_ISO3166['BZ'] = "Belize";
$phpAds_ISO3166['BJ'] = "Benin"; 
$phpAds_ISO3166['BM'] = "Bermuda";
$phpAds_ISO3166['BT'] = "Bhutan";
$phpAds_ISO3166['BO'] = "Bolivia";
$phpAds_ISO3166['BA'] = "Bosnia Herzegovina";
$phpAds_ISO3166['BW'] = "Botswana";
$phpAds_ISO3166['BV'] = "Isola Bouvet";
$phpAds_ISO3166['BR'] = "Brasile";
$phpAds_ISO3166['IO'] = "Territorio Britannico dell'Oceano Indiano";
$phpAds_ISO3166['BN'] = "Brunei";
$phpAds_ISO3166['BG'] = "Bulgaria";
$phpAds_ISO3166['BF'] = "Burkina Faso"; 
$phpAds_ISO3166['BI'] = "Burundi";
$phpAds_ISO3166['KH'] = "Cambogia";
$phpAds_ISO3166['CM'] = "Camerun"; 
$phpAds_ISO3166['CA'] = "Canada";
$phpAds_ISO3166['CV'] = "Capo Verde"; 
$phpAds_ISO3166['KY'] = "Cayman";
$phpAds_ISO3166['CF'] = "Repubblica Centrafricana";
$phpAds_ISO3166['TD'] = "Ciad"; 
$phpAds_ISO3166['CL'] = "Cile";
$phpAds_ISO3166['CN'] = "Cina";
$phpAds_ISO3166['CX'] = "Isola Christmas"; 
$phpAds_ISO3166['CC'] = "Isole Cocos (Keeling)"; 
$phpAds_ISO3166['CO'] = "Colombia";
$phpAds_ISO3166['KM'] = "Comore";
$phpAds_ISO3166['CG'] = "Congo"; 
$phpAds_ISO3166['CD'] = "Congo, Repubblica Democratica"; 
$phpAds_ISO3166['CK'] = "Isole Cook"; 
$phpAds_ISO3166['CR'] = "Costarica";
$phpAds_ISO3166['CI'] = "Costa d'Avorio"; 
$phpAds_ISO3166['HR'] = "Croazia";
$phpAds_ISO3166['CU'] = "Cuba";
$phpAds_ISO3166['CY'] = "Cipro";
$phpAds_ISO3166['CZ'] = "Repubblica Ceca";
$phpAds_ISO3166['DK'] = "Danimarca";
$phpAds_ISO3166['DJ'] = "Gibuti";
$phpAds_ISO3166['DM'] = "Dominica"; 
$phpAds_ISO3166['DO'] = "Repubblica Dominicana";
$phpAds_ISO3166['TP'] = "Timor Est";
$phpAds_ISO3166['EC'] = "Ecuador";
$phpAds_ISO3166['EG'] = "Egitto";
$phpAds_ISO3166['SV'] = "El Salvador";
$phpAds_ISO3166['GQ'] = "Guinea Equatoriale"; 
$phpAds_ISO3166['ER'] = "Eritrea";
$phpAds_ISO3166['EE'] = "Estonia";
$phpAds_ISO3166['ET'] = "Etiopia";
$phpAds_ISO3166['EU'] = "Unione Europea";
$phpAds_ISO3166['FK'] = "Isole Falkland (o Malvine)";
$phpAds_ISO3166['FO'] = "Isole F&aelig;r&oslash;er"; 
$phpAds_ISO3166['FJ'] = "Figi";
$phpAds_ISO3166['FI'] = "Finlandia";
$phpAds_ISO3166['FR'] = "Francia";
$phpAds_ISO3166['FX'] = "Francia, Metropolitana"; 
$phpAds_ISO3166['GF'] = "Guyana Francese";
$phpAds_ISO3166['PF'] = "Polinesia Francese";
$phpAds_ISO3166['TF'] = "Territori Francesi del Sud";
$phpAds_ISO3166['GA'] = "Gabon"; 
$phpAds_ISO3166['GM'] = "Gambia";
$phpAds_ISO3166['GE'] = "Georgia";
$phpAds_ISO3166['DE'] = "Germania";
$phpAds_ISO3166['GH'] = "Ghana";
$phpAds_ISO3166['GI'] = "Gibilterra";
$phpAds_ISO3166['GR'] = "Grecia";
$phpAds_ISO3166['GL'] = "Groenlandia"; 
$phpAds_ISO3166['GD'] = "Grenada"; 
$phpAds_ISO3166['GP'] = "Guadalupa"; 
$phpAds_ISO3166['GU'] = "Guam"; 
$phpAds_ISO3166['GT'] = "Guatemala";
$phpAds_ISO3166['GN'] = "Guinea"; 
$phpAds_ISO3166['GW'] = "Guinea-Bissau"; 
$phpAds_ISO3166['GY'] = "Guyana";
$phpAds_ISO3166['HT'] = "Haiti";
$phpAds_ISO3166['HM'] = "Isole Heard e Mc Donald"; 
$phpAds_ISO3166['VA'] = "Citt del Vaticano"; 
$phpAds_ISO3166['HN'] = "Honduras";
$phpAds_ISO3166['HK'] = "Hong Kong";
$phpAds_ISO3166['HU'] = "Ungheria";
$phpAds_ISO3166['IS'] = "Islanda"; 
$phpAds_ISO3166['IN'] = "India";
$phpAds_ISO3166['ID'] = "Indonesia";
$phpAds_ISO3166['IR'] = "Iran, Repubblica Islamica";
$phpAds_ISO3166['IQ'] = "Iraq";
$phpAds_ISO3166['IE'] = "Irlanda";
$phpAds_ISO3166['IL'] = "Israele";
$phpAds_ISO3166['IT'] = "Italia";
$phpAds_ISO3166['JM'] = "Giamaica";
$phpAds_ISO3166['JP'] = "Giappone";
$phpAds_ISO3166['JO'] = "Giordania";
$phpAds_ISO3166['KZ'] = "Kazakistan";
$phpAds_ISO3166['KE'] = "Kenya";
$phpAds_ISO3166['KI'] = "Kiribati"; 
$phpAds_ISO3166['KP'] = "Corea, Repubblica Democratica di"; 
$phpAds_ISO3166['KR'] = "Corea, Repubblica di"; 
$phpAds_ISO3166['KW'] = "Kuwait";
$phpAds_ISO3166['KG'] = "Kirghizistan"; 
$phpAds_ISO3166['LA'] = "Laos";
$phpAds_ISO3166['LV'] = "Lettonia";
$phpAds_ISO3166['LB'] = "Libano";
$phpAds_ISO3166['LS'] = "Lesotho";
$phpAds_ISO3166['LR'] = "Liberia";
$phpAds_ISO3166['LY'] = "Libia";
$phpAds_ISO3166['LI'] = "Liechtenstein"; 
$phpAds_ISO3166['LT'] = "Lituania"; 
$phpAds_ISO3166['LU'] = "Lussemburgo";
$phpAds_ISO3166['MO'] = "Macao";
$phpAds_ISO3166['MK'] = "Macedonia";
$phpAds_ISO3166['MG'] = "Madagascar"; 
$phpAds_ISO3166['MW'] = "Malawi";
$phpAds_ISO3166['MY'] = "Malaysia";
$phpAds_ISO3166['MV'] = "Maldive";
$phpAds_ISO3166['ML'] = "Mali"; 
$phpAds_ISO3166['MT'] = "Malta";
$phpAds_ISO3166['MH'] = "Isole Marshall"; 
$phpAds_ISO3166['MQ'] = "Martinica"; 
$phpAds_ISO3166['MR'] = "Mauritania";
$phpAds_ISO3166['MU'] = "Maurizio";
$phpAds_ISO3166['YT'] = "Mayotte"; 
$phpAds_ISO3166['MX'] = "Messico";
$phpAds_ISO3166['FM'] = "Micronesia, Stati Federati della"; 
$phpAds_ISO3166['MD'] = "Moldavia, Repubblica di";
$phpAds_ISO3166['MC'] = "Monaco";
$phpAds_ISO3166['MN'] = "Mongolia";
$phpAds_ISO3166['MS'] = "Montserrat"; 
$phpAds_ISO3166['MA'] = "Marocco";
$phpAds_ISO3166['MZ'] = "Mozambico";
$phpAds_ISO3166['MM'] = "Myanmar";
$phpAds_ISO3166['NA'] = "Namibia";
$phpAds_ISO3166['NR'] = "Nauru"; 
$phpAds_ISO3166['NP'] = "Nepal";
$phpAds_ISO3166['NL'] = "Paesi Bassi";
$phpAds_ISO3166['AN'] = "Antille Olandesi";
$phpAds_ISO3166['NC'] = "Nuova Caledonia"; 
$phpAds_ISO3166['NZ'] = "Nuova Zelanda";
$phpAds_ISO3166['NI'] = "Nicaragua";
$phpAds_ISO3166['NE'] = "Niger"; 
$phpAds_ISO3166['NG'] = "Nigeria";
$phpAds_ISO3166['NU'] = "Niue"; 
$phpAds_ISO3166['NF'] = "Isola Norfolk"; 
$phpAds_ISO3166['MP'] = "Marianne Settentrionali"; 
$phpAds_ISO3166['NO'] = "Norvegia";
$phpAds_ISO3166['OM'] = "Oman";
$phpAds_ISO3166['PK'] = "Pakistan";
$phpAds_ISO3166['PW'] = "Palau"; 
$phpAds_ISO3166['PA'] = "Panama";
$phpAds_ISO3166['PG'] = "Papua Nuova Guinea";
$phpAds_ISO3166['PY'] = "Paraguay";
$phpAds_ISO3166['PE'] = "Per&ugrave;";
$phpAds_ISO3166['PH'] = "Filippine";
$phpAds_ISO3166['PN'] = "Isole Pitcairn"; 
$phpAds_ISO3166['PL'] = "Polonia";
$phpAds_ISO3166['PT'] = "Territori Palestinesi Occupati";
$phpAds_ISO3166['PT'] = "Portogallo";
$phpAds_ISO3166['PR'] = "Portirico"; 
$phpAds_ISO3166['QA'] = "Qatar";
$phpAds_ISO3166['RE'] = "Riunione"; 
$phpAds_ISO3166['RO'] = "Romania";
$phpAds_ISO3166['RU'] = "Russia";
$phpAds_ISO3166['RW'] = "Ruanda";
$phpAds_ISO3166['KN'] = "Saint Kitts e Nevis"; 
$phpAds_ISO3166['LC'] = "Saint Lucia"; 
$phpAds_ISO3166['VC'] = "Saint Vincent e Grenadines"; 
$phpAds_ISO3166['WS'] = "Samoa";
$phpAds_ISO3166['SM'] = "San Marino";
$phpAds_ISO3166['ST'] = "S&atilde;o Tom&eacute; e Principe"; 
$phpAds_ISO3166['SA'] = "Arabia Saudita";
$phpAds_ISO3166['SN'] = "Senegal"; 
$phpAds_ISO3166['SC'] = "Seychelles";
$phpAds_ISO3166['SL'] = "Sierra Leone";
$phpAds_ISO3166['SG'] = "Singapore";
$phpAds_ISO3166['SK'] = "Slovacchia";
$phpAds_ISO3166['SI'] = "Slovenia";
$phpAds_ISO3166['SO'] = "Somalia";
$phpAds_ISO3166['SB'] = "Isole Salomone"; 
$phpAds_ISO3166['ZA'] = "Sudafrica";
$phpAds_ISO3166['GS'] = "Georgia Meridionale e isole South Sandwich"; 
$phpAds_ISO3166['ES'] = "Spagna";
$phpAds_ISO3166['LK'] = "Sri Lanka";
$phpAds_ISO3166['SH'] = "Sant'Elena"; 
$phpAds_ISO3166['PM'] = "Saint Pierre e Miquelon"; 
$phpAds_ISO3166['SD'] = "Sudan";
$phpAds_ISO3166['SR'] = "Suriname";
$phpAds_ISO3166['SJ'] = "Svalbard e isole Jan Mayen"; 
$phpAds_ISO3166['SZ'] = "Swaziland";
$phpAds_ISO3166['SE'] = "Svezia";
$phpAds_ISO3166['CH'] = "Svizzera";
$phpAds_ISO3166['SY'] = "Syrian Arab Republic";
$phpAds_ISO3166['TW'] = "Taiwan, Provincia della Cina";
$phpAds_ISO3166['TJ'] = "Tagikistan";
$phpAds_ISO3166['TZ'] = "Tanzania, Repubblica Unita di";
$phpAds_ISO3166['TH'] = "Thailandia";
$phpAds_ISO3166['TG'] = "Togo"; 
$phpAds_ISO3166['TK'] = "Tokelau"; 
$phpAds_ISO3166['TO'] = "Tonga";
$phpAds_ISO3166['TT'] = "Trinidad e Tobago";
$phpAds_ISO3166['TN'] = "Tunisia";
$phpAds_ISO3166['TR'] = "Turchia";
$phpAds_ISO3166['TM'] = "Turkmenistan";
$phpAds_ISO3166['TC'] = "Isole Turks e Caicos"; 
$phpAds_ISO3166['TV'] = "Tuvalu"; 
$phpAds_ISO3166['UG'] = "Uganda";
$phpAds_ISO3166['UA'] = "Ucraina";
$phpAds_ISO3166['AE'] = "Emirati Arabi Uniti"; 
$phpAds_ISO3166['GB'] = "Gran Bretagna";
$phpAds_ISO3166['US'] = "Stati Uniti";
$phpAds_ISO3166['UM'] = "United States Minor Outlying Islands"; 
$phpAds_ISO3166['UY'] = "Uruguay";
$phpAds_ISO3166['UZ'] = "Uzbekistan";
$phpAds_ISO3166['VU'] = "Vanuatu";
$phpAds_ISO3166['VE'] = "Venezuela";
$phpAds_ISO3166['VN'] = "Vietnam";
$phpAds_ISO3166['VG'] = "Isole Vergini, Britanniche"; 
$phpAds_ISO3166['VI'] = "Isole Vergini, Statunitensi"; 
$phpAds_ISO3166['WF'] = "Isole Wallis e Futuna"; 
$phpAds_ISO3166['EH'] = "Sahara Occidentale"; 
$phpAds_ISO3166['YE'] = "Yemen";
$phpAds_ISO3166['YU'] = "Yugoslavia";
$phpAds_ISO3166['ZM'] = "Zambia";
$phpAds_ISO3166['ZW'] = "Zimbabwe";


// MaxMind Geo-IP special codes
$phpAds_ISO3166['A1'] = "Proxy Anonimo";
$phpAds_ISO3166['A2'] = "Provider Satellitare";


?>
